@@ -18,6 +18,7 @@ import org.af.commons.errorhandling.ErrorHandler;
 import org.af.commons.widgets.InfiniteProgressPanel;
 import org.af.commons.widgets.InfiniteProgressPanel.AbortListener;
 import org.af.gMCP.config.Configuration;
+import org.af.gMCP.config.VersionComparator;
 import org.af.gMCP.gui.datatable.CellEditorE;
 import org.af.gMCP.gui.datatable.DataFramePanel;
 import org.af.gMCP.gui.datatable.DataTable;
@@ -40,7 +41,7 @@ public class CreateGraphGUI extends JFrame implements WindowListener, AbortListe
 	public InfiniteProgressPanel glassPane;
 	protected static Log logger = LogFactory.getLog(CreateGraphGUI.class);
 	
-	public CreateGraphGUI(String graph, double[] pvalues, boolean debug, double grid) {
+	public CreateGraphGUI(String graph, double[] pvalues, boolean debug, double grid, boolean experimentalFeatures) {
 		super("gMCP GUI");
 		Locale.setDefault(Locale.US);
 		JComponent.setDefaultLocale(Locale.US); 
@@ -49,9 +50,11 @@ public class CreateGraphGUI extends JFrame implements WindowListener, AbortListe
 		if (grid>0) {
 			Configuration.getInstance().getGeneralConfig().setGridSize((int)grid);
 		}
+		Configuration.getInstance().getGeneralConfig().setExperimental(experimentalFeatures);
 		try {		
 			Configuration.getInstance().getGeneralConfig().setRVersionNumber(RControl.getR().eval("paste(R.version$major,R.version$minor,sep=\".\")").asRChar().getData()[0]);
 			Configuration.getInstance().getGeneralConfig().setVersionNumber(RControl.getR().eval("gMCP:::gMCPVersion()").asRChar().getData()[0]);
+			this.setTitle("gMCP GUI "+Configuration.getInstance().getGeneralConfig().getVersionNumber());
 		} catch (Exception e) {
 			// This is no vital information and will fail for e.g. R 2.8.0, so no error handling here...
 			logger.warn("Package version could not be set:\n"+e.getMessage());
@@ -113,11 +116,11 @@ public class CreateGraphGUI extends JFrame implements WindowListener, AbortListe
 			}
 		}).start();
 		
-		/* javax.swing.SwingUtilities.invokeLater(new Runnable() {
+		javax.swing.SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
 				 VersionComparator.getOnlineVersion();
 			}
-		});	*/
+		});
 	}
 	
 	/**
@@ -133,7 +136,7 @@ public class CreateGraphGUI extends JFrame implements WindowListener, AbortListe
 		CreateGraphGUI.grid = grid;
 		javax.swing.SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
-				new CreateGraphGUI(CreateGraphGUI.graphStr, new double[] {}, CreateGraphGUI.debug, CreateGraphGUI.grid);
+				new CreateGraphGUI(CreateGraphGUI.graphStr, new double[] {}, CreateGraphGUI.debug, CreateGraphGUI.grid, true);
 			}
 		});		
 	}
@@ -151,7 +154,7 @@ public class CreateGraphGUI extends JFrame implements WindowListener, AbortListe
 	}
 
 	public static void main(String[] args) {
-		new CreateGraphGUI("graph", new double[] {}, true,  10);
+		new CreateGraphGUI("graph", new double[] {}, true,  10, true);
 	}
 
 	public void windowActivated(WindowEvent e) {}
