@@ -76,7 +76,7 @@ public class Edge {
 			} else {
 				alpha = Math.atan(-y/x)/(Math.PI*2)*360+((x<0)?180:0);
 			}
-			alpha = alpha + 10;
+			alpha = alpha + 15;
 			k1 = x1 + (int)(Math.cos(alpha*(Math.PI*2)/360)*d/2);
 			k2 = y1 - (int)(Math.sin(alpha*(Math.PI*2)/360)*d/2);
 		} else {
@@ -286,53 +286,60 @@ public class Edge {
 	 */
 	public static TeXIcon getTeXIcon(JFrame parent, String s, int points) {
 		String latex = "";
-		try {				
-			int openBracket = 0;
-			boolean waitingForDenominator = false;
-			String nominator = "";			
-			s.replaceAll("ε", "\\varepsilon");	
-			s.replaceAll(" ", "");
-			for (int i=0;i<s.length(); i++) {
-				String c = ""+s.charAt(i);	
-				if (c.equals("(")) openBracket++;				
-				if (c.equals(")")) openBracket--;				
-				if ( (c.equals("+") || c.equals("-") || c.equals("*") || 
-						(c.equals(")") &&  (i+1)<s.length() && !(s.charAt(i+1)+"").equals("/")) ) && openBracket == 0) {
-					String start = s.substring(0, i+1);										
-					if (waitingForDenominator) {
-						if (c.equals(")")) {
-							latex += "\\frac{"+nominator+"}{"+start+"}";
-						} else {
-							latex += "\\frac{"+nominator+"}{"+start.substring(0, i)+"}"+c;
-						}
-						waitingForDenominator = false;
-					} else {
-						latex += start;
-					}
-					s = s.substring(i+1, s.length());
-					i=-1;
-				}
-				if (c.equals("/")) {					
-					nominator = s.substring(0, i);
-					s = s.substring(i+1, s.length());
-					i=-1;
-					waitingForDenominator = true;
-				}
-			}
-			if (waitingForDenominator) {
-				latex += "\\frac{"+nominator+"}{"+s+"}";				
+		try {	
+			if (s.indexOf("E-")!=-1) {
+				latex = s.replaceAll("E-", "}{10^{");
+				latex = "\\frac{"+latex+"}}";
 			} else {
-				latex += s;
-			}			
-			latex = latex.replaceAll("\\*", Configuration.getInstance().getGeneralConfig().getTimesSymbol());			
-			latex = latex.replaceAll("\\(", "{(");
-			latex = latex.replaceAll("\\)", ")}");
+				int openBracket = 0;
+				boolean waitingForDenominator = false;
+				String nominator = "";			
+				s.replaceAll("ε", "\\varepsilon");	
+				s.replaceAll(" ", "");
+				for (int i=0;i<s.length(); i++) {
+					String c = ""+s.charAt(i);	
+					if (c.equals("(")) openBracket++;				
+					if (c.equals(")")) openBracket--;				
+					if ( (c.equals("+") || c.equals("-") || c.equals("*") || 
+							(c.equals(")") &&  (i+1)<s.length() && !(s.charAt(i+1)+"").equals("/")) ) && openBracket == 0) {
+						String start = s.substring(0, i+1);										
+						if (waitingForDenominator) {
+							if (c.equals(")")) {
+								latex += "\\frac{"+nominator+"}{"+start+"}";
+							} else {
+								latex += "\\frac{"+nominator+"}{"+start.substring(0, i)+"}"+c;
+							}
+							waitingForDenominator = false;
+						} else {
+							latex += start;
+						}
+						s = s.substring(i+1, s.length());
+						i=-1;
+					}
+					if (c.equals("/")) {					
+						nominator = s.substring(0, i);
+						s = s.substring(i+1, s.length());
+						i=-1;
+						waitingForDenominator = true;
+					}
+				}
+				if (waitingForDenominator) {
+					latex += "\\frac{"+nominator+"}{"+s+"}";				
+				} else {
+					latex += s;
+				}			
+				latex = latex.replaceAll("\\*", Configuration.getInstance().getGeneralConfig().getTimesSymbol());			
+				latex = latex.replaceAll("\\(", "{(");
+				latex = latex.replaceAll("\\)", ")}");
+			}
 			logger.debug("LaTeX string:"+latex);		
 			TeXFormula formula = new TeXFormula(latex);//
-			formula = new TeXFormula("\\mathbf{"+latex+"}");
+			formula = new TeXFormula("\\mathbf{"+latex+"}");			
+			if (latex.indexOf("frac")==-1 && latex.length()>4) points = (int) (points*0.7);
 			return formula.createTeXIcon(TeXConstants.ALIGN_CENTER, points);
 		} catch(Exception e) {
-			e.printStackTrace();
+			//e.printStackTrace();
+			//System.out.println("Error: "+latex);
 			JOptionPane.showMessageDialog(parent, "Invalid weight string:\n"+latex+"\nError:\n"+e.getMessage(), "Invalid input", JOptionPane.ERROR_MESSAGE);
 			TeXFormula formula = new TeXFormula("Syntax Error");
 			return formula.createTeXIcon(TeXConstants.ALIGN_CENTER, points); 
@@ -381,27 +388,11 @@ public class Edge {
 		return ew.getVariables();
 	}
 
-	public double[] getW(Hashtable<String, Double> ht) {
+	public double getW(Hashtable<String, Double> ht) {
 		return ew.getWeight(ht);
 	}
 	
 	public EdgeWeight getEdgeWeight() {
 		return ew;
 	}
-
-	public String getEpsilonString(Hashtable<String, Double> ht) {
-		double[] w = ew.getWeight(ht);
-		if (w.length<2) {
-			return null;
-		}
-		String s = "c(";
-		for (int i=1; i<w.length; i++) {
-			s += w[i];
-			if (i!=w.length-1) {
-				s += ", ";
-			}
-		}
-		s += ")";
-		return s;
-	}
 }
